pub struct Clock { /* private fields */ }Expand description
Clock control.
Implementations
Sourceimpl Clock
impl Clock
pub const unsafe fn from_ptr(ptr: *mut ()) -> Self
pub const fn as_ptr(&self) -> *mut ()
Sourcepub const fn tasks_hfclkstart(self) -> Reg<u32, W>
pub const fn tasks_hfclkstart(self) -> Reg<u32, W>
Start HFXO crystal oscillator.
Sourcepub const fn tasks_hfclkstop(self) -> Reg<u32, W>
pub const fn tasks_hfclkstop(self) -> Reg<u32, W>
Stop HFXO crystal oscillator.
Sourcepub const fn tasks_lfclkstart(self) -> Reg<u32, W>
pub const fn tasks_lfclkstart(self) -> Reg<u32, W>
Start LFCLK.
Sourcepub const fn tasks_lfclkstop(self) -> Reg<u32, W>
pub const fn tasks_lfclkstop(self) -> Reg<u32, W>
Stop LFCLK.
Sourcepub const fn tasks_ctstart(self) -> Reg<u32, W>
pub const fn tasks_ctstart(self) -> Reg<u32, W>
Start calibration timer.
Sourcepub const fn tasks_ctstop(self) -> Reg<u32, W>
pub const fn tasks_ctstop(self) -> Reg<u32, W>
Stop calibration timer.
Sourcepub const fn events_hfclkstarted(self) -> Reg<u32, RW>
pub const fn events_hfclkstarted(self) -> Reg<u32, RW>
HFXO crystal oscillator started.
Sourcepub const fn events_lfclkstarted(self) -> Reg<u32, RW>
pub const fn events_lfclkstarted(self) -> Reg<u32, RW>
LFCLK started.
Sourcepub const fn events_done(self) -> Reg<u32, RW>
pub const fn events_done(self) -> Reg<u32, RW>
Calibration of LFRC completed.
Sourcepub const fn events_ctto(self) -> Reg<u32, RW>
pub const fn events_ctto(self) -> Reg<u32, RW>
Calibration timer timeout.
Sourcepub const fn events_ctstarted(self) -> Reg<u32, RW>
pub const fn events_ctstarted(self) -> Reg<u32, RW>
Calibration timer has been started and is ready to process new tasks.
Sourcepub const fn events_ctstopped(self) -> Reg<u32, RW>
pub const fn events_ctstopped(self) -> Reg<u32, RW>
Calibration timer has been stopped and is ready to process new tasks.
Sourcepub const fn hfclkrun(self) -> Reg<Hfclkrun, R>
pub const fn hfclkrun(self) -> Reg<Hfclkrun, R>
Status indicating that HFCLKSTART task has been triggered.
Sourcepub const fn lfclkrun(self) -> Reg<Lfclkrun, R>
pub const fn lfclkrun(self) -> Reg<Lfclkrun, R>
Status indicating that LFCLKSTART task has been triggered.
Sourcepub const fn lfclksrccopy(self) -> Reg<Lfclksrccopy, R>
pub const fn lfclksrccopy(self) -> Reg<Lfclksrccopy, R>
Copy of LFCLKSRC register, set when LFCLKSTART task was triggered.
Sourcepub const fn hfxodebounce(self) -> Reg<Hfxodebounce, RW>
pub const fn hfxodebounce(self) -> Reg<Hfxodebounce, RW>
HFXO debounce time. The HFXO is started by triggering the TASKS_HFCLKSTART task.
Sourcepub const fn traceconfig(self) -> Reg<Traceconfig, RW>
pub const fn traceconfig(self) -> Reg<Traceconfig, RW>
Clocking options for the trace port debug interface.